rm(list=ls(all=TRUE))  # clear all variables
# Programmed by Greg Francis (gfrancis@purdue.edu) September 2013

# Exp. 4 (Mani, Mullainathan, Shafir & Zhao, 2013) between subjects design, Ravens measure only

# define properties of experiments
n1 = 23 # Poor Hard
n2 = 24 # Poor Easy
n3 = 23 # Rich Hard
n4 = 26 # Rich Easy

SampleSize = c(n1, n2, n3, n4)
Means = c(0.25366, 0.440043, 0.462015, 0.466469)  
SampleSD = c(0.163211738, 0.21160652, 0.226056315, 0.253655825) 
SDs = SampleSD
#Pooled SD
pooleddf = sum(SampleSize) -4
pooledVar = sum(SampleSD^2 *(SampleSize-1))/pooleddf
SDs = sqrt(pooledVar) +0*SampleSD  

numRepeats = 100000
numSuccess = 0

NS1=0
NS2=0
NS3=0
NS4=0
NS5=0
NS6=0

for(rep in c(1:numRepeats)){

# Draw random samples and run the tests, then compute power for those test from that sample
    PoorHard  <- rnorm(n1, mean=Means[1], sd=SDs[1])
	PoorEasy <- rnorm(n2, mean=Means[2], sd=SDs[2])	
    RichHard  <- rnorm(n3, mean=Means[3], sd=SDs[3])
    RichEasy  <- rnorm(n4, mean=Means[4], sd=SDs[4])
    				
	# Set up for ANOVA
	Condition <- c()
	Difficulty<-c()
	Result <-c()
	
	for(i in c(1:n1)){
		Condition <- c(Condition, "Poor")
		Difficulty<-c(Difficulty, "Hard")
		Result <- c(Result, PoorHard[i])
	}
	for(i in c(1:n2)){
		Condition <- c(Condition, "Poor")
		Difficulty<-c(Difficulty, "Easy")
		Result <- c(Result, PoorEasy[i])
	}
	for(i in c(1:n3)){
		Condition <- c(Condition, "Rich")
		Difficulty<-c(Difficulty, "Hard")
		Result <- c(Result, RichHard[i])
	}
	for(i in c(1:n4)){
		Condition <- c(Condition, "Rich")
		Difficulty<-c(Difficulty, "Easy")
		Result <- c(Result, RichEasy[i])
	}
				
	# One-way ANOVA 
	dataTwoWay = data.frame(Condition = Condition, Difficulty = Difficulty, Result = Result)
	out <- anova(lm(Result ~ Condition* Difficulty, dataTwoWay))
	thing<-out$`Pr(>F)`
	interactionP = thing[3]
	thing<-out$`Mean Sq`
	MSE = thing[4]
	dfMSE = pooleddf
	
	# Independent t-tests (it is not clear why they did not use contrasts)
	# Easy (rich vs. poor) - predicted null
	test1 <- t.test(PoorEasy, RichEasy)
	p1<- test1$p.value
		
	# Hard (rich vs. poor)
	test2 <- t.test(PoorHard, RichHard)
	p2<- test2$p.value
	
	# Rich (hard vs. easy) - predicted null
	test3 <- t.test(RichEasy, RichHard)
	p3<- test3$p.value

	# Poor (hard vs. easy)
	test4 <- t.test(PoorEasy, PoorHard)
	p4<- test4$p.value	

	# Contrast (Poor vs. Rich)
	weights <- c(-1, -1, 1,  1)
	nweights <- c(weights[1]/sqrt(n1), weights[2]/sqrt(n2), weights[3]/sqrt(n3), weights[4]/sqrt(n4))
	L = weights[1]*mean(PoorHard) + weights[2]*mean(PoorEasy) + weights[3]*mean(RichHard) + weights[4]*mean(RichEasy) 
	t= abs(L)/sqrt(sum(nweights*nweights)*MSE) 		
	contrastP1 <-  2 * (1 - pt(t, df= dfMSE))	
				
		# See if all tests rejects as predicted 
		if (interactionP <=0.05 && p1 >0.05 && p2 <=0.05 && p3 >0.05 && p4 <=0.05 && contrastP1<=0.05)	
		{
			numSuccess = numSuccess +1
			}		
			
		if(interactionP <=0.05){NS1=NS1+1}	
		if(p1>0.05){NS2=NS2+1}	
		if(p2<=0.05){NS3=NS3+1}	
		if(p3>0.05){NS4=NS4+1}	
		if(p4<=0.05){NS5=NS5+1}	
		if(contrastP1<=0.05){NS6=NS6+1}	

}

cat("------\n",numSuccess/numRepeats, "\n")
cat("------\n Interaction ", NS1/numRepeats, "\n")
cat("Easy ", NS2/numRepeats, "\n")
cat("Hard ", NS3/numRepeats, "\n")
cat("Rich ", NS4/numRepeats, "\n")
cat("Poor ", NS5/numRepeats, "\n")
cat("Contrast ", NS6/numRepeats, "\n")



